#!/usr/bin/env python

# Copyright 2023 Earth Sciences Department, BSC-CNS
#
# This file is part of HERMES.
#
# HERMES is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# HERMESv3 is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with HERMES. If not, see <http://www.gnu.org/licenses/>.

import subprocess
import os
import sys
from setuptools import find_packages
from setuptools import setup
from issuestoboard import __version__


# Get the version number from the relevant file
version = __version__

with open("README.rst", "r") as f:
    long_description = f.read()

setup(
    name="IssuesToBoard",
    license="GNU GPL v3",
    # platforms=["GNU/Linux Debian"],
    version=version,
    description="IssuesToBoard",
    long_description=long_description,
    long_description_content_type="text/x-rst",
    author="Carles Tena Medina",
    author_email="carles.tena@bsc.es",
    url="https://earth.bsc.es/gitlab/...",

    keywords=["GitLab", "Kanban", "NextCloud",],
    install_requires=[
        "requests",
        "pandas",
        "configargparse",

    ],
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering :: Atmospheric Science"
    ],
    package_data={"": [
        "README.rst",
        "CHANGELOG.rst",
        "LICENSE.rst",
    ]
    },
    data_files=[(".", ["LICENSE.rst", "CHANGELOG.rst", ]),
                ],

    include_package_data=True,

    entry_points={
        "console_scripts": [
            "hermes_delta = hermes.hermesv3_d.hermesv3_d.hermes:run",
        ],
    },
)
